@@ -56,9 +56,29 @@ def clean_data(string):
     string = re.sub(" incorporated", " inc", string)
     string = re.sub(" apartment", " apt", string)
     string = re.sub(" square(\s|$|,)", " sq\\1", string)
+    string = re.sub("department", "dept", string)
+
+    string = re.sub("fed[^\s]{0,4} cred[^\s]{0,2} un[^\s]{0,4}", "fcu", string)
+
+    string = re.sub("home ?owners association", "hoa", string)
+    string = re.sub("home ?owners assoc[^\s]{0,3}", "hoa", string)
+    string = re.sub("hoa,? inc", "hoa", string)
+
+    string = re.sub("national association", "na", string)
+
+    string = re.sub("housing authy", "housing authority", string) # this replacement is being placed before any of the other housing authority replacements because "authy" appears in both PHA and RHA names
+    string = re.sub("housing authority, inc", "housing authority", string)
+
     string = re.sub("redevelopment and housing authority", "rha", string)
-    string = re.sub("redevelopment and housing auth\.?", "rha", string)
+    string = re.sub("redevelopment and housing auth[^\s]?", "rha", string)
     string = re.sub("redevelopment and housing", "rha", string)
+    string = re.sub("redevelopment housing authority", "rha", string)
+
+    string = re.sub("public housing authority", "pha", string)
+    string = re.sub("housing authority", "pha", string)
+    string = re.sub("housing and redevelopment authority", "pha", string)
+
+    
 
     string = re.sub(" et\.?\s?al\.?$", "", string)
     string = re.sub(
