@@ -19,11 +19,16 @@ def filter_companies(name):
     # Probable people performs poorly on bank names. Working to update training dataset but this is a quick fix for now
 
     try:
+        val = pp.tag(name)
         return (
-            (pp.tag(name)[1] != "Person")
+            (val[1] != "Person")
+            or 'CorporationNameOrganization' in val[0]
+            or 'CorporationNameBranchIdentifier' in val[0]
+            or 'CorporationLegalType' in val[0]
             or ("|and|" in name)
             or (name.count(" ") == 0)
             or (re.search(" bank$", name))
+            or 'citibank' in name
             or ("bennington crossing" in name)
         ) and not name[0].isdigit()
     except:
@@ -42,6 +47,10 @@ def filter_people(name):
         val = pp.tag(name)
         return (
             (val[1] == "Person")
+            and 'CorporationNameOrganization' not in val[0]
+            and 'CorporationNameBranchIdentifier' not in val[0]
+            and 'CorporationLegalType' not in val[0]
+            and 'citibank' not in name
             and ("|and|" not in name)
             and (name.count(" ") != 0)
             and not (re.search(" bank$", name))
